# -*- coding: utf-8 -*-
#-------------------------------------------------------------------------------
# This file is part of typedcols package (https://pypi.python.org/pypi/typedcols).
#
# Copyright (c) since 2016, CESNET, z. s. p. o.
# Author: Pavel Kácha <pavel.kacha@cesnet.cz>
# Use of this source is governed by an ISC license, see LICENSE file.
#-------------------------------------------------------------------------------


import os
import sys
import json


#
# Import local version of typedcols library, so that we can insert correct version
# number into documentation.
#
sys.path.insert(0, os.path.abspath('.'))
import typedcols


# -- Load custom metadata ------------------------------------------------------

# These metadata further describe the exact package version and repository
# revision for which the documentation is being generated. This information will
# be inserted into documentation index page.

with open('metadata.json') as json_metadata_file:
    custom_metadata = json.load(json_metadata_file)

def setup(app):
    app.add_config_value('build_suite', custom_metadata['suite'], 'env')


# -- General configuration -----------------------------------------------------


# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.ifconfig',
    'sphinx.ext.todo',
    'sphinx.ext.coverage',
    'sphinx.ext.viewcode',
    'sphinx.ext.githubpages']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['doc/_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'manual'

# General information about the project.
project = u'typedcols'
copyright = u'since 2016, CESNET, z.s.p.o.'
author = u'Pavel Kácha'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.s
version = typedcols.__version__
# The full version, including alpha/beta/rc tags.
release = typedcols.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['doc/_build', 'resources', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# Define additional rst replacement strings. These are inserting metadata values,
# that have been loaded previously.
rst_epilog = """
.. |codename| replace:: **{codename}**
.. |suite| replace:: *{suite}*
.. |bversion| replace:: *{bversion}*
.. |revision| replace:: ``{revision}``
.. |bnumber| replace:: *- {bnumber}*
""".format(**custom_metadata)


# -- Options for HTML output ---------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['doc/_static']


# -- Options for HTMLHelp output -----------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'typedcols'


# -- Options for LaTeX output --------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'typedcols.tex', u'typedcols - Python library providing typed collections - Documentation',
     u'Pavel Kácha', 'manual'),
]


# -- Options for manual page output --------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'typedcols', u'typedcols - Python library providing typed collections - Documentation',
     [author], 1)
]


# -- Options for Texinfo output ------------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'typedcols', u'typedcols - Python library providing typed collections - Documentation',
     author, 'typedcols', 'One line description of project.',
     'Miscellaneous'),
]


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'python': ('https://docs.python.org/3.4', None)}
